==> zio-aws-kafka_2.13-5.17.104.3-sources.jar: zio/aws/kafka/model/ListConfigurationsResponse.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListConfigurationsResponse(
    configurations: Option[Iterable[zio.aws.kafka.model.Configuration]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse = {
    import ListConfigurationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse
      .builder()
      .optionallyWith(
        configurations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.configurations)
      .optionallyWith(
        nextToken.map(value => __string.unwrap(value): java.lang.String)
      )(_.nextToken)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ListConfigurationsResponse.ReadOnly =
    zio.aws.kafka.model.ListConfigurationsResponse.wrap(buildAwsValue())
}
object ListConfigurationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ListConfigurationsResponse =
      zio.aws.kafka.model.ListConfigurationsResponse(
        configurations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def configurations: Option[List[zio.aws.kafka.model.Configuration.ReadOnly]]
    def nextToken: Option[__string]
    def getConfigurations
        : ZIO[Any, AwsError, List[zio.aws.kafka.model.Configuration.ReadOnly]] =
      AwsError.unwrapOptionField("configurations", configurations)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse
  ) extends zio.aws.kafka.model.ListConfigurationsResponse.ReadOnly {
    override val configurations
        : Option[List[zio.aws.kafka.model.Configuration.ReadOnly]] = scala
      .Option(impl.configurations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kafka.model.Configuration.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] = scala
      .Option(impl.nextToken())
      .map(value => zio.aws.kafka.model.primitives.__string(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse
  ): zio.aws.kafka.model.ListConfigurationsResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_2.13-5.17.151.1-sources.jar: zio/aws/kafka/model/ListConfigurationsResponse.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ListConfigurationsResponse(
    configurations: Option[Iterable[zio.aws.kafka.model.Configuration]] = None,
    nextToken: Option[__string] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse = {
    import ListConfigurationsResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse
      .builder()
      .optionallyWith(
        configurations.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.configurations)
      .optionallyWith(nextToken.map(value => value: java.lang.String))(
        _.nextToken
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.ListConfigurationsResponse.ReadOnly =
    zio.aws.kafka.model.ListConfigurationsResponse.wrap(buildAwsValue())
}
object ListConfigurationsResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.ListConfigurationsResponse =
      zio.aws.kafka.model.ListConfigurationsResponse(
        configurations.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        nextToken.map(value => value)
      )
    def configurations: Option[List[zio.aws.kafka.model.Configuration.ReadOnly]]
    def nextToken: Option[__string]
    def getConfigurations
        : ZIO[Any, AwsError, List[zio.aws.kafka.model.Configuration.ReadOnly]] =
      AwsError.unwrapOptionField("configurations", configurations)
    def getNextToken: ZIO[Any, AwsError, __string] =
      AwsError.unwrapOptionField("nextToken", nextToken)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse
  ) extends zio.aws.kafka.model.ListConfigurationsResponse.ReadOnly {
    override val configurations
        : Option[List[zio.aws.kafka.model.Configuration.ReadOnly]] = scala
      .Option(impl.configurations())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.kafka.model.Configuration.wrap(item)
        }.toList
      )
    override val nextToken: Option[__string] =
      scala.Option(impl.nextToken()).map(value => value: __string)
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.ListConfigurationsResponse
  ): zio.aws.kafka.model.ListConfigurationsResponse.ReadOnly = new Wrapper(impl)
}
